@@ -16,8 +16,12 @@ arraytype = ny.ndarray
 arrayfunc = lambda func, *args : [func(*items) for items in izip()]
 
 
-_functions = {'min':min,
-              'max':max}
+_functions = {'min':'min',
+              'max':'max',
+              ###Ned to check these functions
+              'mean': 'mean',
+              'med': 'median',
+              }
 
 
 def rollsingle(self, func, window = 20, name = None, **kwargs):
@@ -118,8 +122,10 @@ class TimeSeries(dynts.TimeSeries):
         return hash.getts()
     
     def log(self, name = None, **kwargs):
-        raise NotImplementedError
-    
+        v = ny.log(self._data)
+        name = name or 'log(%s,%s)' % (self.name,lag)
+        return self.clone(self._date,v,name)
+            
     def delta(self, lag = 1, name = None, **kwargs):
         self.precondition(lag<len(self) and lag > 0,dynts.DyntsOutOfBound)
         v = self._data[lag:] - self._data[:-lag]
@@ -133,8 +139,7 @@ class TimeSeries(dynts.TimeSeries):
         return self.clone(self._date[lag:],v,name)
     
     def _rollapply(self, func, window = 20, **kwargs):
-        fs = _functions.get(func,None)
-        if fs:
-            return rollsingle(self, func, window = window, **kwargs)
-            
+        func = _functions.get(func,None) or func
+        return rollsingle(self, func, window = window, **kwargs)
+        
     
\ No newline at end of file
