@@ -11,10 +11,10 @@ class CustomProvider(DataProvider):
 class CustomLoader(TimeSerieLoader):
     data = {}
     
-    def onresult(self, ticker, field, provider, result, logger, backend, **kwargs):
+    def onresult(self, symbol, result, logger, backend, **kwargs):
         '''Store result in the class data dictionary'''
-        symbol = self.getsymbol(ticker, field, provider.code)
-        self.data[symbol] = result
+        ticker = self.getsymbol(symbol.ticker, symbol.field, symbol.provider.code)
+        self.data[ticker] = result
         return result
         
 
